(function (factory) {
    if (typeof module === "object" && typeof module.exports === "object") {
        var v = factory(require, exports);
        if (v !== undefined) module.exports = v;
    }
    else if (typeof define === "function" && define.amd) {
        define(["require", "exports", "@tsparticles/engine", "./Utils.js", "./Options/Classes/Light.js"], factory);
    }
})(function (require, exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.ExternalLighter = void 0;
    const engine_1 = require("@tsparticles/engine");
    const Utils_js_1 = require("./Utils.js");
    const Light_js_1 = require("./Options/Classes/Light.js");
    class ExternalLighter extends engine_1.ExternalInteractorBase {
        constructor(container, engine) {
            super(container);
            this._engine = engine;
        }
        clear() {
        }
        init() {
        }
        interact() {
            const container = this.container, options = container.actualOptions, interactivity = container.interactivity;
            if (!options.interactivity.events.onHover.enable || interactivity.status !== "pointermove") {
                return;
            }
            const mousePos = interactivity.mouse.position;
            if (!mousePos) {
                return;
            }
            container.canvas.draw(ctx => {
                (0, Utils_js_1.drawLight)(container, ctx, mousePos);
            });
        }
        isEnabled(particle) {
            const container = this.container, mouse = container.interactivity.mouse, interactivity = particle?.interactivity ?? container.actualOptions.interactivity, events = interactivity.events;
            if (!(events.onHover.enable && mouse.position)) {
                return false;
            }
            const res = (0, engine_1.isInArray)(Utils_js_1.lightMode, events.onHover.mode);
            if (res && interactivity.modes.light) {
                const lightGradient = interactivity.modes.light.area.gradient;
                container.canvas.mouseLight = {
                    start: (0, engine_1.rangeColorToRgb)(this._engine, lightGradient.start),
                    stop: (0, engine_1.rangeColorToRgb)(this._engine, lightGradient.stop),
                };
            }
            return res;
        }
        loadModeOptions(options, ...sources) {
            if (!options.light) {
                options.light = new Light_js_1.Light();
            }
            for (const source of sources) {
                options.light.load(source?.light);
            }
        }
        reset() {
        }
    }
    exports.ExternalLighter = ExternalLighter;
});
